@@ -30,6 +30,7 @@ import os
 import numbers
 
 from consts import *
+import mcf as mcf_mod
 
 
 _libscrypt_soname = ctypes.util.find_library('scrypt')
@@ -136,6 +137,9 @@ def scrypt_mcf(password, salt=None, N=SCRYPT_N, r=SCRYPT_r, p=SCRYPT_p):
         raise ValueError('salt must be 1-16 bytes')
     if N > 2**31:
         raise ValueError('N > 2**31 not supported')
+    if b'\0' in password:
+        raise ValueError('scrypt_mcf password must not contain zero bytes')
+
     hash = scrypt(password, salt, N, r, p)
 
     h64 = base64.b64encode(hash)
@@ -160,6 +164,8 @@ def scrypt_mcf_check(mcf, password):
         raise TypeError
     if not isinstance(password, bytes):
         raise TypeError
+    if len(mcf) != 124 or b'\0' in password:
+        return mcf_mod.scrypt_mcf_check(scrypt, mcf, password)
 
     mcfbuf = ctypes.create_string_buffer(mcf)
     ret = _libscrypt_check(mcfbuf, password)
